pub struct ResetSignalAllocation(/* private fields */);Expand description
Structure meant to be stored in a static to signal applications that they have been factory-resetted by a runner
It is expected to have one such structure for each application supporting factory-reset
Implementations
Sourceimpl ResetSignalAllocation
impl ResetSignalAllocation
pub const fn new() -> Self
pub fn load(&self) -> ResetSignal
pub fn set_factory_reset(&self) -> bool
pub fn set_config_changed(&self)
Sourcepub fn ack_factory_reset(&self) -> bool
pub fn ack_factory_reset(&self) -> bool
Factory reset can be acknowledged so that the application can restart working
A configuration change cannot be acknowledged as it requires a power cycle to be taken into account.