Modules
- api
- This (incomplete!) API loosely follows PKCS#11 v3.
- config
- mechanisms
- serde_
extensions - Extensions to the core Trussed syscalls.
- types
Macros
Structs
Enums
Traits
- Attestation
Client - Certificate
Client - Read/Write + Delete certificates
- Counter
Client - Create counters, increment existing counters.
- Crypto
Client - Trussed Client interface that Trussed apps can rely on.
- Filesystem
Client - Read/Write/Delete files, iterate over directories.
- Management
Client - All the other methods that are fit to expose.
- Poll
Client - Lowest level interface, use one of the higher level ones.
- UiClient
- User-interfacing functionality.